use strict;
use warnings;

=begin MetaPOD::JSON v1.0.0

{
    "namespace":"Example",
    "inherits": [ "Bar", "Baz" ]
}

=end MetaPOD::JSON

=cut

=for MetaPOD::JSON v1.0.0 { "inherits": "Quux" }

=cut

